@@ -2,37 +2,46 @@
 #' @description This function computes the performances of the l1-spectral clustering algorithm in terms of Normalized Mutualized Information (NMI).
 #' @param Results Output of the function \code{l1_spectralclustering()}.
 #' @param A The adjacency matrix of the graph to cluster.
-#' @importFrom NMI NMI
+#' @importFrom aricode NMI
+#' @importFrom aricode AMI
+#' @importFrom aricode ARI
 #' @seealso \code{\link{l1_spectralclustering}}, \code{\link{l1spectral}}.
-#' @return The Normalized Mutualized Information (NMI) score.
+#' @return The Normalized Mutualized Information (NMI), Adjusted Mutualized Information (AMI) and Adjusted Rand Index (ARI) scores.
 #' @author Camille Champion, Magali Champion
 #' @export
 #' @examples
 #'  #############################################################
-#'  # Generating toy data
+#'  # Computing the performances
 #'  #############################################################
-#'  Data <- CreateDataSet(k=3, n=20, p=list(p_inside=0.1,p_outside=0.1))
+#'
+#'  data(ToyData)
+#'
+#'  results <- l1_spectralclustering(A = ToyData$A_hat, pen = "lasso",
+#'              k=2, elements = c(1,4))
+#'
+#'  ComputePerformances(Results=results,A=ToyData$A)
 #'
 
 ComputePerformances <- function(Results, A){
   # Results: output of the function l1_spectralclustering()
   # A: true adjacency matrix
 
-  # Output: NMI score
+  # Output: NMI, AMI and ARI scores
 
   # first, find the clusters in the adjacency matrix
   graph <- graph_from_adjacency_matrix(A,mode="undirected")
   clusters <- components(graph)$membership
-  clusters <- cbind(c(1:length(clusters)),clusters)
 
   if (!is.null(ncol(Results$comm))){
     clus_est <- Results$comm%*%c(1:ncol(Results$comm))
   } else {
     clus_est <- Results$comm
   }
-  clus_est <- cbind(c(1:length(clus_est)),clus_est)
+  clus_est <- as.vector(clus_est)
 
-  score <- NMI(clus_est,clusters)
-  score <- score$value
-  return(score)
+  NMI <- NMI(clus_est,clusters)
+  AMI <- AMI(clus_est,clusters)
+  ARI <- ARI(clus_est,clusters)
+
+  return(score=list(NMI=NMI,AMI=AMI,ARI=ARI))
 }
